Class: Aws::Glacier::Job

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/job.rbs,
lib/aws-sdk-glacier/job.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id, vault_name, id, options = {}) ⇒ Job #initialize(options = {}) ⇒ Job

Returns a new instance of Job.

Overloads:

  • #initialize(account_id, vault_name, id, options = {}) ⇒ Job

    Parameters:

    • account_id (String)
    • vault_name (String)
    • id (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ Job

    Options Hash (options):

    • :account_id (required, String)
    • :vault_name (required, String)
    • :id (required, String)
    • :client (Client)


13
14
15
# File 'sig/job.rbs', line 13

def initialize: (String account_id, String vault_name, String id, Hash[Symbol, untyped] options) -> void
| (account_id: String, vault_name: String, id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#account_idString

Returns:

  • (String)


18
# File 'sig/job.rbs', line 18

def account_id: () -> String

#actionString

The job type. This value is either ArchiveRetrieval, InventoryRetrieval, or Select.

Returns:

  • (String)


31
# File 'sig/job.rbs', line 31

def action: () -> ("ArchiveRetrieval" | "InventoryRetrieval" | "Select")

#archive_idString

The archive ID requested for a select job or archive retrieval. Otherwise, this field is null.

Returns:

  • (String)


34
# File 'sig/job.rbs', line 34

def archive_id: () -> ::String

#archive_sha256_tree_hashString

The SHA256 tree hash of the entire archive for an archive retrieval. For inventory retrieval or select jobs, this field is null.

Returns:

  • (String)


67
# File 'sig/job.rbs', line 67

def archive_sha256_tree_hash: () -> ::String

#archive_size_in_bytesInteger

For an archive retrieval job, this value is the size in bytes of the archive being requested for download. For an inventory retrieval or select job, this value is null.

Returns:

  • (Integer)


52
# File 'sig/job.rbs', line 52

def archive_size_in_bytes: () -> ::Integer

#clientClient

Returns:



222
# File 'lib/aws-sdk-glacier/job.rb', line 222

def client: () -> Client

#completedBoolean

The job status. When a job is completed, you get the job's output using Get Job Output (GET output).

Returns:

  • (Boolean)


43
# File 'sig/job.rbs', line 43

def completed: () -> bool

#completion_dateTime

The UTC time that the job request completed. While the job is in progress, the value is null.

Returns:

  • (Time)


61
# File 'sig/job.rbs', line 61

def completion_date: () -> ::Time

#creation_dateTime

The UTC date when the job was created. This value is a string representation of ISO 8601 date format, for example "2012-03-20T17:03:43.221Z".

Returns:

  • (Time)


40
# File 'sig/job.rbs', line 40

def creation_date: () -> ::Time

#dataTypes::GlacierJobDescription

Returns the data for this Aws::Glacier::Job. Calls Client#describe_job if #data_loaded? is false.

Returns:



94
# File 'sig/job.rbs', line 94

def data: () -> Types::GlacierJobDescription

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



97
# File 'sig/job.rbs', line 97

def data_loaded?: () -> bool

#get_output(options = {}, &block) ⇒ Types::GetJobOutputOutput

Examples:

Request syntax with placeholder values


job.get_output({
  range: "string",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :range (String)

    The range of bytes to retrieve from the output. For example, if you want to download the first 1,048,576 bytes, specify the range as bytes=0-1048575. By default, this operation downloads the entire output.

    If the job output is large, then you can use a range to retrieve a portion of the output. This allows you to download the entire output in smaller chunks of bytes. For example, suppose you have 1 GB of job output you want to download and you decide to download 128 MB chunks of data at a time, which is a total of eight Get Job Output requests. You use the following process to download the job output:

    1. Download a 128 MB chunk of output by specifying the appropriate byte range. Verify that all 128 MB of data was received.

    2. Along with the data, the response includes a SHA256 tree hash of the payload. You compute the checksum of the payload on the client and compare it with the checksum you received in the response to ensure you received all the expected data.

    3. Repeat steps 1 and 2 for all the eight 128 MB chunks of output data, each time specifying the appropriate byte range.

    4. After downloading all the parts of the job output, you have a list of eight checksum values. Compute the tree hash of these values to find the checksum of the entire output. Using the DescribeJob API, obtain job information of the job that provided you the output. The response includes the checksum of the entire archive stored in Amazon Glacier. You compare this value with the checksum you computed to ensure you have downloaded the entire archive content with no errors.

Returns:



101
# File 'sig/job.rbs', line 101

def get_output: (

#idString Also known as: job_id

Returns:

  • (String)


24
# File 'sig/job.rbs', line 24

def id: () -> String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


425
426
427
428
429
430
431
# File 'lib/aws-sdk-glacier/job.rb', line 425

def identifiers
  {
    account_id: @account_id,
    vault_name: @vault_name,
    id: @id
  }
end

#inventory_retrieval_parametersTypes::InventoryRetrievalJobDescription

Parameters used for range inventory retrieval.



76
# File 'sig/job.rbs', line 76

def inventory_retrieval_parameters: () -> Types::InventoryRetrievalJobDescription

#inventory_size_in_bytesInteger

For an inventory retrieval job, this value is the size in bytes of the inventory requested for download. For an archive retrieval or select job, this value is null.

Returns:

  • (Integer)


55
# File 'sig/job.rbs', line 55

def inventory_size_in_bytes: () -> ::Integer

#job_descriptionString

The job description provided when initiating the job.

Returns:

  • (String)


28
# File 'sig/job.rbs', line 28

def job_description: () -> ::String

#job_output_pathString

Contains the job output location.

Returns:

  • (String)


79
# File 'sig/job.rbs', line 79

def job_output_path: () -> ::String

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::Glacier::Job. Returns self making it possible to chain methods.

job.reload.data

Returns:

  • (self)


90
# File 'sig/job.rbs', line 90

def load: () -> self

#output_locationTypes::OutputLocation

Contains the location where the data from the select job is stored.



85
# File 'sig/job.rbs', line 85

def output_location: () -> Types::OutputLocation

#retrieval_byte_rangeString

The retrieved byte range for archive retrieval jobs in the form StartByteValue-EndByteValue. If no range was specified in the archive retrieval, then the whole archive is retrieved. In this case, StartByteValue equals 0 and EndByteValue equals the size of the archive minus 1. For inventory retrieval or select jobs, this field is null.

Returns:

  • (String)


70
# File 'sig/job.rbs', line 70

def retrieval_byte_range: () -> ::String

#select_parametersTypes::SelectParameters

Contains the parameters used for a select.



82
# File 'sig/job.rbs', line 82

def select_parameters: () -> Types::SelectParameters

#sha256_tree_hashString

For an archive retrieval job, this value is the checksum of the archive. Otherwise, this value is null.

The SHA256 tree hash value for the requested range of an archive. If the InitiateJob request for an archive specified a tree-hash aligned range, then this field returns a value.

If the whole archive is retrieved, this value is the same as the ArchiveSHA256TreeHash value.

This field is null for the following:

  • Archive retrieval jobs that specify a range that is not tree-hash aligned

^ ^

  • Archival jobs that specify a range that is equal to the whole archive, when the job status is InProgress

^ ^

  • Inventory jobs

  • Select jobs

Returns:

  • (String)


64
# File 'sig/job.rbs', line 64

def sha256_tree_hash: () -> ::String

#sns_topicString

An Amazon SNS topic that receives notification.

Returns:

  • (String)


58
# File 'sig/job.rbs', line 58

def sns_topic: () -> ::String

#status_codeString

The status code can be InProgress, Succeeded, or Failed, and indicates the status of the job.

Returns:

  • (String)


46
# File 'sig/job.rbs', line 46

def status_code: () -> ("InProgress" | "Succeeded" | "Failed")

#status_messageString

A friendly message that describes the job status.

Returns:

  • (String)


49
# File 'sig/job.rbs', line 49

def status_message: () -> ::String

#tierString

The tier to use for a select or an archive retrieval. Valid values are Expedited, Standard, or Bulk. Standard is the default.

Returns:

  • (String)


73
# File 'sig/job.rbs', line 73

def tier: () -> ::String

#vaultVault

Returns:



107
# File 'sig/job.rbs', line 107

def vault: () -> Vault

#vault_arnString

The Amazon Resource Name (ARN) of the vault from which an archive retrieval was requested.

Returns:

  • (String)


37
# File 'sig/job.rbs', line 37

def vault_arn: () -> ::String

#vault_nameString

Returns:

  • (String)


21
# File 'sig/job.rbs', line 21

def vault_name: () -> String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::Glacier::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/aws-sdk-glacier/job.rb', line 340

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end