Class: Aws::Glacier::Plugins::Checksums Private
- Inherits:
-
Seahorse::Client::Plugin
- Object
- Seahorse::Client::Plugin
- Aws::Glacier::Plugins::Checksums
- Defined in:
- lib/aws-sdk-glacier/plugins/checksums.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Computes the :checksum of the HTTP request body for operations that require the X-Amz-Sha256-Tree-Hash header. This includes:
-
:complete_multipart_upload -
:upload_archive -
:upload_multipart_part
The :upload_archive and :upload_multipart_part operations accept a :checksum request parameter. If this param is present, then the checksum is assumed to be the proper tree hash of the file to be uploaded. If this param is not present, then the required tree hash checksum will be generated.
The :complete_multipart_upload operation does not accept a checksum and this plugin will always compute this of the HTTP request body on your behalf.
Defined Under Namespace
Classes: Handler
Constant Summary collapse
- CHECKSUM_OPERATIONS =
This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.
[ :upload_archive, :upload_multipart_part, ]