Class: Aws::Glacier::Types::AddTagsToVaultInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glacier/types.rb

Overview

The input values for AddTagsToVault.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single ‘-’ (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (‘-’) in the ID.

Returns:

  • (String)


93
94
95
96
97
98
99
# File 'lib/aws-sdk-glacier/types.rb', line 93

class AddTagsToVaultInput < Struct.new(
  :account_id,
  :vault_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to add to the vault. Each tag is composed of a key and a value. The value can be an empty string.

Returns:

  • (Hash<String,String>)


93
94
95
96
97
98
99
# File 'lib/aws-sdk-glacier/types.rb', line 93

class AddTagsToVaultInput < Struct.new(
  :account_id,
  :vault_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#vault_nameString

The name of the vault.

Returns:

  • (String)


93
94
95
96
97
98
99
# File 'lib/aws-sdk-glacier/types.rb', line 93

class AddTagsToVaultInput < Struct.new(
  :account_id,
  :vault_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end