Class: Aws::Glacier::Types::DeleteArchiveInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glacier::Types::DeleteArchiveInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glacier/types.rb
Overview
Provides options for deleting an archive from an Amazon Glacier vault.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The
AccountIdvalue is the AWS account ID of the account that owns the vault. -
#archive_id ⇒ String
The ID of the archive to delete.
-
#vault_name ⇒ String
The name of the vault.
Instance Attribute Details
#account_id ⇒ String
The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single ‘-’ (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (‘-’) in the ID.
380 381 382 383 384 385 386 |
# File 'lib/aws-sdk-glacier/types.rb', line 380 class DeleteArchiveInput < Struct.new( :account_id, :vault_name, :archive_id) SENSITIVE = [] include Aws::Structure end |
#archive_id ⇒ String
The ID of the archive to delete.
380 381 382 383 384 385 386 |
# File 'lib/aws-sdk-glacier/types.rb', line 380 class DeleteArchiveInput < Struct.new( :account_id, :vault_name, :archive_id) SENSITIVE = [] include Aws::Structure end |
#vault_name ⇒ String
The name of the vault.
380 381 382 383 384 385 386 |
# File 'lib/aws-sdk-glacier/types.rb', line 380 class DeleteArchiveInput < Struct.new( :account_id, :vault_name, :archive_id) SENSITIVE = [] include Aws::Structure end |