Class: Aws::Glacier::Types::DeleteVaultNotificationsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glacier::Types::DeleteVaultNotificationsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glacier/types.rb
Overview
Provides options for deleting a vault notification configuration from an Amazon Glacier vault.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The
AccountIdvalue is the AWS account ID of the account that owns the vault. -
#vault_name ⇒ String
The name of the vault.
Instance Attribute Details
#account_id ⇒ String
The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single ‘-’ (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (‘-’) in the ID.
448 449 450 451 452 453 |
# File 'lib/aws-sdk-glacier/types.rb', line 448 class DeleteVaultNotificationsInput < Struct.new( :account_id, :vault_name) SENSITIVE = [] include Aws::Structure end |
#vault_name ⇒ String
The name of the vault.
448 449 450 451 452 453 |
# File 'lib/aws-sdk-glacier/types.rb', line 448 class DeleteVaultNotificationsInput < Struct.new( :account_id, :vault_name) SENSITIVE = [] include Aws::Structure end |