Class: Aws::Glacier::Types::InventoryRetrievalJobDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glacier::Types::InventoryRetrievalJobDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glacier/types.rb
Overview
Describes the options for a range inventory retrieval job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_date ⇒ Time
The end of the date range in UTC for vault inventory retrieval that includes archives created before this date.
-
#format ⇒ String
The output format for the vault inventory list, which is set by the InitiateJob request when initiating a job to retrieve a vault inventory.
-
#limit ⇒ String
The maximum number of inventory items returned per vault inventory retrieval request.
-
#marker ⇒ String
An opaque string that represents where to continue pagination of the vault inventory retrieval results.
-
#start_date ⇒ Time
The start of the date range in Universal Coordinated Time (UTC) for vault inventory retrieval that includes archives created on or after this date.
Instance Attribute Details
#end_date ⇒ Time
The end of the date range in UTC for vault inventory retrieval that
includes archives created before this date. This value should be a
string in the ISO 8601 date format, for example
2013-03-20T17:03:43Z.
1313 1314 1315 1316 1317 1318 1319 1320 1321 |
# File 'lib/aws-sdk-glacier/types.rb', line 1313 class InventoryRetrievalJobDescription < Struct.new( :format, :start_date, :end_date, :limit, :marker) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
The output format for the vault inventory list, which is set by the
InitiateJob request when initiating a job to retrieve a vault
inventory. Valid values are CSV and JSON.
1313 1314 1315 1316 1317 1318 1319 1320 1321 |
# File 'lib/aws-sdk-glacier/types.rb', line 1313 class InventoryRetrievalJobDescription < Struct.new( :format, :start_date, :end_date, :limit, :marker) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ String
The maximum number of inventory items returned per vault inventory retrieval request. This limit is set when initiating the job with the a InitiateJob request.
1313 1314 1315 1316 1317 1318 1319 1320 1321 |
# File 'lib/aws-sdk-glacier/types.rb', line 1313 class InventoryRetrievalJobDescription < Struct.new( :format, :start_date, :end_date, :limit, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An opaque string that represents where to continue pagination of the
vault inventory retrieval results. You use the marker in a new
InitiateJob request to obtain additional inventory items. If
there are no more inventory items, this value is null. For more
information, see Range Inventory Retrieval.
1313 1314 1315 1316 1317 1318 1319 1320 1321 |
# File 'lib/aws-sdk-glacier/types.rb', line 1313 class InventoryRetrievalJobDescription < Struct.new( :format, :start_date, :end_date, :limit, :marker) SENSITIVE = [] include Aws::Structure end |
#start_date ⇒ Time
The start of the date range in Universal Coordinated Time (UTC) for
vault inventory retrieval that includes archives created on or after
this date. This value should be a string in the ISO 8601 date
format, for example 2013-03-20T17:03:43Z.
1313 1314 1315 1316 1317 1318 1319 1320 1321 |
# File 'lib/aws-sdk-glacier/types.rb', line 1313 class InventoryRetrievalJobDescription < Struct.new( :format, :start_date, :end_date, :limit, :marker) SENSITIVE = [] include Aws::Structure end |