Class: Aws::Glacier::Types::ListMultipartUploadsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glacier/types.rb

Overview

Provides options for retrieving list of in-progress multipart uploads for an Amazon Glacier vault.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single ‘-’ (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (‘-’) in the ID.

Returns:

  • (String)


1573
1574
1575
1576
1577
1578
1579
1580
# File 'lib/aws-sdk-glacier/types.rb', line 1573

class ListMultipartUploadsInput < Struct.new(
  :account_id,
  :vault_name,
  :marker,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#limitInteger

Specifies the maximum number of uploads returned in the response body. If this value is not specified, the List Uploads operation returns up to 50 uploads.

Returns:

  • (Integer)


1573
1574
1575
1576
1577
1578
1579
1580
# File 'lib/aws-sdk-glacier/types.rb', line 1573

class ListMultipartUploadsInput < Struct.new(
  :account_id,
  :vault_name,
  :marker,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An opaque string used for pagination. This value specifies the upload at which the listing of uploads should begin. Get the marker value from a previous List Uploads response. You need only include the marker if you are continuing the pagination of results started in a previous List Uploads request.

Returns:

  • (String)


1573
1574
1575
1576
1577
1578
1579
1580
# File 'lib/aws-sdk-glacier/types.rb', line 1573

class ListMultipartUploadsInput < Struct.new(
  :account_id,
  :vault_name,
  :marker,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#vault_nameString

The name of the vault.

Returns:

  • (String)


1573
1574
1575
1576
1577
1578
1579
1580
# File 'lib/aws-sdk-glacier/types.rb', line 1573

class ListMultipartUploadsInput < Struct.new(
  :account_id,
  :vault_name,
  :marker,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end