Class: Aws::Glacier::Types::ListVaultsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glacier/types.rb

Overview

Contains the Amazon Glacier response to your request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

The vault ARN at which to continue pagination of the results. You use the marker in another List Vaults request to obtain more vaults in the list.



1800
1801
1802
1803
1804
1805
# File 'lib/aws-sdk-glacier/types.rb', line 1800

class ListVaultsOutput < Struct.new(
  :vault_list,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#vault_listArray<Types::DescribeVaultOutput>

List of vaults.



1800
1801
1802
1803
1804
1805
# File 'lib/aws-sdk-glacier/types.rb', line 1800

class ListVaultsOutput < Struct.new(
  :vault_list,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end