Class: Aws::Glacier::Types::UploadListElement
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glacier::Types::UploadListElement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glacier/types.rb
Overview
A list of in-progress multipart uploads for a vault.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#archive_description ⇒ String
The description of the archive that was specified in the Initiate Multipart Upload request.
-
#creation_date ⇒ Time
The UTC time at which the multipart upload was initiated.
-
#multipart_upload_id ⇒ String
The ID of a multipart upload.
-
#part_size_in_bytes ⇒ Integer
The part size, in bytes, specified in the Initiate Multipart Upload request.
-
#vault_arn ⇒ String
The Amazon Resource Name (ARN) of the vault that contains the archive.
Instance Attribute Details
#archive_description ⇒ String
The description of the archive that was specified in the Initiate Multipart Upload request.
2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-glacier/types.rb', line 2286 class UploadListElement < Struct.new( :multipart_upload_id, :vault_arn, :archive_description, :part_size_in_bytes, :creation_date) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The UTC time at which the multipart upload was initiated.
2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-glacier/types.rb', line 2286 class UploadListElement < Struct.new( :multipart_upload_id, :vault_arn, :archive_description, :part_size_in_bytes, :creation_date) SENSITIVE = [] include Aws::Structure end |
#multipart_upload_id ⇒ String
The ID of a multipart upload.
2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-glacier/types.rb', line 2286 class UploadListElement < Struct.new( :multipart_upload_id, :vault_arn, :archive_description, :part_size_in_bytes, :creation_date) SENSITIVE = [] include Aws::Structure end |
#part_size_in_bytes ⇒ Integer
The part size, in bytes, specified in the Initiate Multipart Upload request. This is the size of all the parts in the upload except the last part, which may be smaller than this size.
2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-glacier/types.rb', line 2286 class UploadListElement < Struct.new( :multipart_upload_id, :vault_arn, :archive_description, :part_size_in_bytes, :creation_date) SENSITIVE = [] include Aws::Structure end |
#vault_arn ⇒ String
The Amazon Resource Name (ARN) of the vault that contains the archive.
2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-glacier/types.rb', line 2286 class UploadListElement < Struct.new( :multipart_upload_id, :vault_arn, :archive_description, :part_size_in_bytes, :creation_date) SENSITIVE = [] include Aws::Structure end |