Class: Aws::Glacier::Vault

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/vault.rbs,
lib/aws-sdk-glacier/vault.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id, name, options = {}) ⇒ Vault #initialize(options = {}) ⇒ Vault

Returns a new instance of Vault.

Overloads:

  • #initialize(account_id, name, options = {}) ⇒ Vault

    Parameters:

    • account_id (String)
    • name (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ Vault

    Options Hash (options):

    • :account_id (required, String)
    • :name (required, String)
    • :client (Client)


13
14
15
# File 'sig/vault.rbs', line 13

def initialize: (String account_id, String name, Hash[Symbol, untyped] options) -> void
| (account_id: String, name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#accountAccount

Returns:



83
# File 'sig/vault.rbs', line 83

def account: () -> Account

#account_idString

Returns:

  • (String)


18
# File 'sig/vault.rbs', line 18

def account_id: () -> String

#archive(id) ⇒ Archive

Parameters:

  • id (String)

Returns:



86
# File 'sig/vault.rbs', line 86

def archive: (String id) -> Archive

#clientClient

Returns:



87
# File 'lib/aws-sdk-glacier/vault.rb', line 87

def client: () -> Client

#completed_jobs(options = {}) ⇒ Job::Collection

Examples:

Request syntax with placeholder values


completed_jobs = vault.completed_jobs({
  statuscode: "string",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :statuscode (String)

    The type of job status to return. You can specify the following values: InProgress, Succeeded, or Failed.

Returns:



89
# File 'sig/vault.rbs', line 89

def completed_jobs: (

#create(options = {}) ⇒ Types::CreateVaultOutput

Examples:

Request syntax with placeholder values


vault.create()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



53
# File 'sig/vault.rbs', line 53

def create: (

#creation_dateTime

The Universal Coordinated Time (UTC) date when the vault was created. This value should be a string in the ISO 8601 date format, for example 2012-03-20T17:03:43.221Z.

Returns:

  • (Time)


28
# File 'sig/vault.rbs', line 28

def creation_date: () -> ::Time

#dataTypes::DescribeVaultOutput

Returns the data for this Aws::Glacier::Vault. Calls Client#describe_vault if #data_loaded? is false.

Returns:



46
# File 'sig/vault.rbs', line 46

def data: () -> Types::DescribeVaultOutput

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



49
# File 'sig/vault.rbs', line 49

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


vault.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


58
# File 'sig/vault.rbs', line 58

def delete: (

#failed_jobs(options = {}) ⇒ Job::Collection

Examples:

Request syntax with placeholder values


failed_jobs = vault.failed_jobs({
  completed: "string",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :completed (String)

    The state of the jobs to return. You can specify true or false.

Returns:



95
# File 'sig/vault.rbs', line 95

def failed_jobs: (

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


615
616
617
618
619
620
# File 'lib/aws-sdk-glacier/vault.rb', line 615

def identifiers
  {
    account_id: @account_id,
    name: @name
  }
end

#initiate_inventory_retrieval(options = {}) ⇒ Job

Examples:

Request syntax with placeholder values


vault.initiate_inventory_retrieval()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



63
# File 'sig/vault.rbs', line 63

def initiate_inventory_retrieval: (

#initiate_multipart_upload(options = {}) ⇒ MultipartUpload

Examples:

Request syntax with placeholder values


multipartupload = vault.initiate_multipart_upload({
  archive_description: "string",
  part_size: 1,
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :archive_description (String)

    The archive description that you are uploading in parts.

    The part size must be a megabyte (1024 KB) multiplied by a power of 2, for example 1048576 (1 MB), 2097152 (2 MB), 4194304 (4 MB), 8388608 (8 MB), and so on. The minimum allowable part size is 1 MB, and the maximum is 4 GB (4096 MB).

  • :part_size (Integer)

    The size of each part except the last, in bytes. The last part can be smaller than this part size.

Returns:



68
# File 'sig/vault.rbs', line 68

def initiate_multipart_upload: (

#job(id) ⇒ Job

Parameters:

  • id (String)

Returns:



101
# File 'sig/vault.rbs', line 101

def job: (String id) -> Job

#jobs(options = {}) ⇒ Job::Collection

Examples:

Request syntax with placeholder values


jobs = vault.jobs({
  statuscode: "string",
  completed: "string",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :statuscode (String)

    The type of job status to return. You can specify the following values: InProgress, Succeeded, or Failed.

  • :completed (String)

    The state of the jobs to return. You can specify true or false.

Returns:



104
# File 'sig/vault.rbs', line 104

def jobs: (

#jobs_in_progress(options = {}) ⇒ Job::Collection

Examples:

Request syntax with placeholder values


jobs_in_progress = vault.jobs_in_progress({
  completed: "string",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :completed (String)

    The state of the jobs to return. You can specify true or false.

Returns:



111
# File 'sig/vault.rbs', line 111

def jobs_in_progress: (

#last_inventory_dateTime

The Universal Coordinated Time (UTC) date when Amazon Glacier completed the last vault inventory. This value should be a string in the ISO 8601 date format, for example 2012-03-20T17:03:43.221Z.

Returns:

  • (Time)


31
# File 'sig/vault.rbs', line 31

def last_inventory_date: () -> ::Time

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::Glacier::Vault. Returns self making it possible to chain methods.

vault.reload.data

Returns:

  • (self)


42
# File 'sig/vault.rbs', line 42

def load: () -> self

#multipart_uplaods(options = {}) ⇒ MultipartUpload::Collection

Examples:

Request syntax with placeholder values


vault.multipart_uplaods()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



117
# File 'sig/vault.rbs', line 117

def multipart_uplaods: (

#multipart_upload(id) ⇒ MultipartUpload

Parameters:

  • id (String)

Returns:



122
# File 'sig/vault.rbs', line 122

def multipart_upload: (String id) -> MultipartUpload

#nameString Also known as: vault_name

Returns:

  • (String)


21
# File 'sig/vault.rbs', line 21

def name: () -> String

#notificationNotification

Returns:



125
# File 'sig/vault.rbs', line 125

def notification: () -> Notification

#number_of_archivesInteger

The number of archives in the vault as of the last inventory date. This field will return null if an inventory has not yet run on the vault, for example if you just created the vault.

Returns:

  • (Integer)


34
# File 'sig/vault.rbs', line 34

def number_of_archives: () -> ::Integer

#size_in_bytesInteger

Total size, in bytes, of the archives in the vault as of the last inventory date. This field will return null if an inventory has not yet run on the vault, for example if you just created the vault.

Returns:

  • (Integer)


37
# File 'sig/vault.rbs', line 37

def size_in_bytes: () -> ::Integer

#succeeded_jobs(options = {}) ⇒ Job::Collection

Examples:

Request syntax with placeholder values


succeeded_jobs = vault.succeeded_jobs({
  completed: "string",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :completed (String)

    The state of the jobs to return. You can specify true or false.

Returns:



128
# File 'sig/vault.rbs', line 128

def succeeded_jobs: (

#upload_archive(options = {}) ⇒ Archive

Examples:

Request syntax with placeholder values


archive = vault.upload_archive({
  archive_description: "string",
  checksum: "string",
  body: "data",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :archive_description (String)

    The optional description of the archive you are uploading.

  • :checksum (String)

    The SHA256 tree hash of the data being uploaded.

  • :body (String, StringIO, File)

    The data to upload.

Returns:



75
# File 'sig/vault.rbs', line 75

def upload_archive: (

#vault_arnString

The Amazon Resource Name (ARN) of the vault.

Returns:

  • (String)


25
# File 'sig/vault.rbs', line 25

def vault_arn: () -> ::String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::Glacier::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/aws-sdk-glacier/vault.rb', line 204

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end