Class: Aws::Glacier::Waiters::VaultExists

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-glacier/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ VaultExists

Returns a new instance of VaultExists.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 15
  • :delay (Integer) — default: 3
  • :before_attempt (Proc)
  • :before_wait (Proc)


85
86
# File 'lib/aws-sdk-glacier/waiters.rb', line 85

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



115
116
117
# File 'lib/aws-sdk-glacier/waiters.rb', line 115

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeVaultOutput

Returns a response object which responds to the following methods:

Options Hash (params):

  • :account_id (required, String)

    The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.

  • :vault_name (required, String)

    The name of the vault.

Returns:



110
# File 'lib/aws-sdk-glacier/waiters.rb', line 110

def wait: (