Class: Aws::Glacier::Waiters::VaultNotExists
- Inherits:
-
Object
- Object
- Aws::Glacier::Waiters::VaultNotExists
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-glacier/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ VaultNotExists
constructor
A new instance of VaultNotExists.
-
#wait(params = {}) ⇒ Types::DescribeVaultOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ VaultNotExists
Returns a new instance of VaultNotExists.
127 128 |
# File 'lib/aws-sdk-glacier/waiters.rb', line 127
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
157 158 159 |
# File 'lib/aws-sdk-glacier/waiters.rb', line 157 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeVaultOutput
Returns a response object which responds to the following methods:
- #vault_arn => String
- #vault_name => String
- #creation_date => Time
- #last_inventory_date => Time
- #number_of_archives => Integer
- #size_in_bytes => Integer
152 |
# File 'lib/aws-sdk-glacier/waiters.rb', line 152
def wait: (
|